@@ -10,7 +10,6 @@
 #include "private/decorationbridge.h"
 #include "decorationbutton.h"
 #include "decorationsettings.h"
-#include "decorationshadow.h"
 
 #include <QCoreApplication>
 #include <QHoverEvent>
@@ -162,10 +161,21 @@ DELEGATE(requestToggleOnAllDesktops)
 DELEGATE(requestToggleShade)
 DELEGATE(requestToggleKeepAbove)
 DELEGATE(requestToggleKeepBelow)
-DELEGATE(requestShowWindowMenu)
 
 #undef DELEGATE
 
+#if KDECORATIONS2_ENABLE_DEPRECATED_SINCE(5, 21)
+void Decoration::requestShowWindowMenu()
+{
+    requestShowWindowMenu(QRect());
+}
+#endif
+
+void Decoration::requestShowWindowMenu(const QRect &rect)
+{
+    d->client->d->requestShowWindowMenu(rect);
+}
+
 void Decoration::requestShowToolTip(const QString &text)
 {
     d->client->d->requestShowToolTip(text);
